# vrsjp

## This program is to confirm the number of vaccinated people in Japan

Download the data from here（http://data.vrs.digital.go.jp/vaccination/opendata/latest/summary_by_date.csv）

The information displayed in this program is the number of new vaccinations for the new coronavirus vaccine. The first inoculation, the second inoculation, and the third inoculation are displayed in different colors.
